==> gtphoto2-framework-0.1.tar.gz: gtphoto2/includes/login.php <==
<?php

/*

    GTPhoto2 - A multi user photo album
    Copyright (C) 2004 Chris Kloosterman

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Author's Email Address:
        kloostec@gavintech.com
    Paper Mail:
        5945 Cassino Road
        Duncan, BC, V9L 4G5, Canada

*/

# This script contains the functions that have
# anything to do with logging in

# function: require_login
# input: auth_level - the required authentication level
# return: none
# description: authenticate to at least the level passed in
function require_login($auth_level = AUTH_FREE) {

	global $errors;
	global $warnings;

	# if the auth_level session var isn't set, we need to auth
	if (!(isset($_SESSION["auth_level"]))
		# if the auth_level in $_SESSION is too high
		# we need more perms
		|| $_SESSION["auth_level"] > $auth_level) {
		
		echo ("<h1>Log in</h1>");
		
                if (count($errors) == 0 && count($warnings) == 0) {
                        # if there's no errors, print the standard prompt
                        if ($_SESSION["auth_level"] && $_SESSION["auth_level"] > $auth_level) {
                                echo ("<p>The user you are logged in as does not have permissions to access this resource.  Please log in as a privileged user.</p>");
                        } else {
                                echo ("<p>You must supply a username and password to access this resource</p>");
                        }
                } else {
                        print_errors();
                }
?>
	<form action="index.php" method="post">
		<table>
		  <tr>
		    <td>User Name</td>
		    <td><input type="text" name="user_name" value="<?=$_REQUEST["user_name"]?>" /></td>
		  </tr>
		  <tr>
		    <td>Password</td>
		    <td><input type="password" name="password" /></td>
		  </tr>
		</table>
	<br />
<?php
        foreach ($_GET as $key => $value) {
                if ($key != "user_name" && key != "password") {
                        echo ("        <input type=\"hidden\" name=\"".clean_form_form($key)."\" value=\"".clean_form_form($value)."\" />\n");
                }
        }
?>
	<input type="hidden" name="next_page" value="<?=$_REQUEST["next_page"]?>" />
	<input type="hidden" name="validator" value="login.php" />
	<input type="submit" value="Log In" />
	</form>
		  
<?php
		include("includes/footer.php");
		exit();
	}
}

?>

==> gtphoto2-framework-0.2.tar.gz: gtphoto2/includes/login.php <==
<?php

/*

    GTPhoto2 - A multi user photo album
    Copyright (C) 2004 Chris Kloosterman

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Author's Email Address:
        kloostec@gavintech.com
    Paper Mail:
        5945 Cassino Road
        Duncan, BC, V9L 4G5, Canada

*/

# This script contains the functions that have
# anything to do with logging in

# function: require_login
# input: auth_level - the required authentication level
# return: none
# description: authenticate to at least the level passed in
function require_login($auth_level = AUTH_FREE) {

	global $errors;
	global $warnings;

	# if the types session var isn't set, we need to auth
	if (!(is_array($_SESSION["types"]))
		# if types in $_SESSION doesn't have the auth_level we want, the user has to log in with someone who has it
		|| array_search($auth_level, $_SESSION["types"]) === false) {
		
		echo ("<h1>Log in</h1>");
		
                if (count($errors) == 0 && count($warnings) == 0) {
                        # if there's no errors, print the standard prompt
                        if (is_array($_SESSION["types"])) {
                                echo ("<p>The user you are logged in as does not have permissions to access this resource.  Please log in as a privileged user.</p>");
                        } else {
                                echo ("<p>You must supply a username and password to access this resource</p>");
                        }
                } else {
                        print_errors();
                }
?>
	<form action="index.php" method="post">
		<table>
		  <tr>
		    <td>User Name:</td>
		    <td><input type="text" name="user_name" value="<?=$_REQUEST["user_name"]?>" style="width: 300px" /></td>
		  </tr>
		  <tr>
		    <td>Password:</td>
		    <td><input type="password" name="password" style="width: 300px" /></td>
		  </tr>
		</table>
	<br />
<?php
	print_hidden_recursive($_REQUEST,"");
?>
	<input type="hidden" name="validator" value="login.php" />
	<input type="submit" value="Log In" />
	</form>
		  
<?php
		include("includes/footer.php");
		exit();
	}
}

function print_hidden_recursive($array,$brackets) {
        foreach ($array as $key => $value) {
                if ($brackets == "" && ($key == "user_name" || $key == "password" || $key == "PHPSESSID" || $key == "validator")) {
                        continue;
                }
                if (is_array($value)) {
                        if ($brackets == "") {
                                $temp = $key;
                        } else {
                                $temp = $brackets . "[$key]";
                        }
                        print_hidden_recursive($array[$key],$temp);
		} else {
                        if ($brackets == "") {
                                $temp = $key;
                        } else {
                                $temp = $brackets . "[$key]";
                        }
                        echo ("<input type=\"hidden\" name=\"$temp\" value=\"".clean_form_form($value)."\" />\n");
                }
        }
}

?>
